@@ -8,7 +8,7 @@ use Exporter 'import';
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2023-09-16'; # DATE
 our $DIST = 'List-Util-Find'; # DIST
-our $VERSION = '0.004'; # VERSION
+our $VERSION = '0.005'; # VERSION
 
 our @EXPORT_OK = qw(
                        hasnum
@@ -66,7 +66,7 @@ List::Util::Find - List utilities related to finding items
 
 =head1 VERSION
 
-This document describes version 0.004 of List::Util::Find (from Perl distribution List-Util-Find), released on 2023-09-16.
+This document describes version 0.005 of List::Util::Find (from Perl distribution List-Util-Find), released on 2023-09-16.
 
 =head1 SYNOPSIS
 
@@ -122,6 +122,17 @@ string. It is equivalent to something like:
 
 except it does not use any module.
 
+=head1 FAQ
+
+=head2 How about hasundef, hasref, hasarrayref, ...?
+
+They are trivial enough:
+
+ first { !defined } @list;
+ first { ref $_ } @list;
+ first { ref $_ eq 'ARRAY' } @list;
+ # and so on
+
 =head1 HOMEPAGE
 
 Please visit the project's homepage at L<https://metacpan.org/release/List-Util-Find>.
